@@ -30,6 +30,10 @@
 #include "legal.h"
 #include <QDir>
 #include "windowcontroller.h"
+#include "translations.h"
+#include "translation.h"
+#include "downloader.h"
+#include "fsmonitor.h"
 
 #ifndef Q_WS_MAEMO_5
 #include <MDeclarativeCache>
@@ -37,6 +41,8 @@
 #define M_DECL_EXPORT
 #endif
 
+#define USER_DIR "/home/user/MyDocs/.n900-quran/"
+
 M_DECL_EXPORT int main(int argc, char *argv[]) {
 #ifndef Q_WS_MAEMO_5
   QApplication *app = MDeclarativeCache::qApplication(argc, argv);
@@ -57,11 +63,17 @@ M_DECL_EXPORT int main(int argc, char *argv[]) {
     }
   }
 
+  FSMonitor monitor;
+
   Settings settings;
   settings.loadFont();
 
+  Downloader downloader;
+
   DataProvider data(DATA_DIR "/text/");
 
+  Translations translations(USER_DIR "translations/", &downloader, &settings, &data);
+
   Bookmarks bookmarks(&settings);
 
   NumberFormatter formatter(&settings);
@@ -73,8 +85,12 @@ M_DECL_EXPORT int main(int argc, char *argv[]) {
   qmlRegisterType<Bookmarks>();
   qmlRegisterType<NumberFormatter>();
   qmlRegisterType<Legal>();
+  qmlRegisterType<Translations>();
+  qmlRegisterType<FSMonitor>();
+  qmlRegisterType<Translation>("Translations", 1, 0, "Translation");
   qmlRegisterType<QuranView>("Quran", 1, 0, "QuranView");
 
+
 #ifndef Q_WS_MAEMO_5
   QDeclarativeView *view = MDeclarativeCache::qDeclarativeView();
 #else
@@ -95,6 +111,9 @@ M_DECL_EXPORT int main(int argc, char *argv[]) {
   view->rootContext()->setContextProperty("_bookmarks", &bookmarks);
   view->rootContext()->setContextProperty("_formatter", &formatter);
   view->rootContext()->setContextProperty("_legal", &legal);
+  view->rootContext()->setContextProperty("_translations", &translations);
+  view->rootContext()->setContextProperty("_downloader", &downloader);
+  view->rootContext()->setContextProperty("_fsmon", &monitor);
 
   if (dev) {
     view->setSource(QUrl::fromLocalFile(QDir::currentPath() + "/main.qml"));
@@ -123,7 +142,12 @@ M_DECL_EXPORT int main(int argc, char *argv[]) {
   int ret = app->exec();
 
   delete view;
+
+#ifndef Q_WS_MAEMO_5
+  // We get a crash deep in the stack from Qt
+  // We will not delete QApplication until I debug that properly
   delete app;
+#endif
 
   return ret;
 }
